@@ -3,6 +3,8 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, cast
 
+from sqlalchemy import text
+from sqlalchemy.ext.asyncio import async_sessionmaker, create_async_engine
 from starlite.plugins.sql_alchemy import SQLAlchemyConfig, SQLAlchemyPlugin
 from starlite.plugins.sql_alchemy.config import (
     SESSION_SCOPE_KEY,
@@ -10,6 +12,7 @@ from starlite.plugins.sql_alchemy.config import (
 )
 
 from starlite_saqlalchemy import db, settings
+from starlite_saqlalchemy.health import AbstractHealthCheck
 
 if TYPE_CHECKING:
     from sqlalchemy.ext.asyncio import AsyncSession
@@ -40,6 +43,29 @@ async def before_send_handler(message: "Message", _: "State", scope: "Scope") ->
             del scope[SESSION_SCOPE_KEY]  # type:ignore[misc]
 
 
+class SQLAlchemyHealthCheck(AbstractHealthCheck):
+    """SQLAlchemy health check."""
+
+    name: str = "db"
+
+    def __init__(self) -> None:
+        self.engine = create_async_engine(
+            settings.db.URL, logging_name="starlite_saqlalchemy.health"
+        )
+        self.session_maker = async_sessionmaker(bind=self.engine)
+
+    async def ready(self) -> bool:
+        """Perform a health check on the database.
+
+        Returns:
+            `True` if healthy.
+        """
+        async with self.session_maker() as session:
+            return (  # type:ignore[no-any-return]  # pragma: no cover
+                await session.execute(text("SELECT 1"))
+            ).scalar_one() == 1
+
+
 config = SQLAlchemyConfig(
     before_send_handler=before_send_handler,
     dependency_key=settings.api.DB_SESSION_DEPENDENCY_KEY,
